@@ -987,8 +987,9 @@ class AgentGroup:
         na_color: str = "xkcd:white",
         xlab: str = "Agent",
         ylab: str = "Opponent",
+        cbarlabel: str = "Average score of the agent",
         show: bool = True,
-    ) -> None:
+    ):
         """plot a heatmap of the results.
 
         Args:
@@ -1012,6 +1013,7 @@ class AgentGroup:
             na_color,
             xlab,
             ylab,
+            cbarlabel=cbarlabel,
             show=show,
         )
 
@@ -1020,9 +1022,10 @@ class AgentGroup:
         agent0: str,
         agent1: str,
         agent: int = 0,
+        sim: Optional[int] = None,
         plot_individual_sim: bool = False,
         show: bool = True,
-    ) -> None:
+    ):
         """plots the choice of an agent in a defined agent pair
 
         Args:
@@ -1038,12 +1041,11 @@ class AgentGroup:
             agent1=agent1,
             agent=agent,
             plot_individual_sim=plot_individual_sim,
+            sim=sim,
             show=show,
         )
 
-    def plot_score(
-        self, agent0: str, agent1: str, agent: int = 0, show: bool = True
-    ) -> None:
+    def plot_score(self, agent0: str, agent1: str, agent: int = 0, show: bool = True):
         """plots the score of an agent in a defined agent pair
 
         Args:
@@ -1064,8 +1066,8 @@ class AgentGroup:
         ylab: str = "",
         xlab: str = "Round",
         show: bool = True,
-    ) -> None:
-        """pPlots the history of an agent in a defined agent pair
+    ):
+        """Plots the history of an agent in a defined agent pair
 
         Args:
             agent0 (str): The name of agent0
@@ -1105,7 +1107,7 @@ class AgentGroup:
 
     def plot_p_k(
         self, agent0: str, agent1: str, level: int, agent: int = 0, show: bool = True
-    ) -> None:
+    ):
         """plots the p_k of a k-ToM agent in a defined agent pair
 
         Args:
@@ -1117,9 +1119,7 @@ class AgentGroup:
         self.__tom_in_group(agent0, agent1, agent)
         plot_p_k(self.__df, agent0, agent1, agent=agent, level=level, show=show)
 
-    def plot_p_self(
-        self, agent0: str, agent1: str, agent: int = 0, show: bool = True
-    ) -> None:
+    def plot_p_self(self, agent0: str, agent1: str, agent: int = 0, show: bool = True):
         """plots the p_self of a k-ToM agent in a defined agent pair
 
         Args:
@@ -1139,7 +1139,7 @@ class AgentGroup:
         level: int = 0,
         agent: int = 0,
         show: bool = True,
-    ) -> None:
+    ):
         """plots the p_self of a k-ToM agent in a defined agent pair
 
         Args:
